# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('taggit', '0002_auto_20150616_2121'),
        ('aldryn_categories', '0004_auto_20150623_0859'),
        ('blog_extension', '0001_initial'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='maylikeplugin',
            name='categories',
        ),
        migrations.RemoveField(
            model_name='maylikeplugin',
            name='tags',
        ),
        migrations.AddField(
            model_name='maylikeplugin',
            name='catagory',
            field=models.ForeignKey(related_name='+', default=None, blank=True, to='aldryn_categories.Category', null=True, on_delete=models.CASCADE),
        ),
        migrations.AddField(
            model_name='maylikeplugin',
            name='tag',
            field=models.ForeignKey(related_name='+', default=None, blank=True, to='taggit.Tag', null=True, on_delete=models.CASCADE),
        ),
    ]
